import click
from .game import play_game
from .recoface import open_camera
from PySide6.QtWidgets import QApplication
from .gui import FaceDetectionApp
import sys
@click.command()
@click.option('--gui', is_flag=True, help='Launch the GUI application.')
@click.option('--game', is_flag=True, help='Play the space shooter game.')
@click.option('-a', '--access-camera', is_flag=True, help='Open the camera and perform face detection.')
@click.option('-fk', '--facial-keypoints', is_flag=True, help='Activate facial keypoints detection.')
def main(gui, game, access_camera, facial_keypoints):
    if gui:
        app = QApplication(sys.argv)
        window = FaceDetectionApp()
        window.show()
        sys.exit(app.exec())
    elif game:
        play_game()
    elif access_camera:
        open_camera(facial_keypoints)
    else:
        click.echo(click.get_current_context().get_help())
        click.echo("This tool is under development, so be patient.")

if __name__ == '__main__':
    main()


from PySide6.QtCore import Qt
from PySide6.QtGui import QIcon

ICON_PATH = "cvtease/asset/laugh.ico"
def apply_window_icon(window):
    icon = QIcon(ICON_PATH)
    window.setWindowIcon(icon)
    
def apply_app_icon(app):
    icon = QIcon(ICON_PATH)
    app.setWindowIcon(icon)
    app.setWindowIcon(icon)
# Window Style
WINDOW_TITLE = "Face Detection App"
WINDOW_GEOMETRY = (100, 100, 800, 600)

# Label Styles
IMAGE_LABEL_ALIGNMENT = Qt.AlignCenter

DEV_LABEL_STYLE = """
    This tool is under development, be patience
"""

# Button Styles
BUTTON_STYLE = """
    QPushButton {
        background-color: #007BFF;
        color: white;
        border-radius: 10px;
        padding: 10px 20px;
        margin: 10px;
    }
    QPushButton:hover {
        background-color: #0056b3;
    }
    QPushButton:pressed {
        background-color: #004080;
    }
"""

# Slider Settings
SLIDER_RANGE = (0, 100)
SLIDER_DEFAULT_VALUE = 50
SLIDER_TICK_INTERVAL = 10
SLIDER_TICK_POSITION = Qt.Horizontal

# Slider Style
SLIDER_STYLE = """
    QSlider::groove:horizontal {
        border: 1px solid #999999;
        height: 8px;
        background: #cccccc;
        margin: 2px 0;
    }
    QSlider::handle:horizontal {
        background: #007BFF;
        border: 1px solid #007BFF;
        width: 18px;
        margin: -2px 0;
        border-radius: 3px;
    }
"""

# ComboBox Items
COMBO_BOX_ITEMS = ["Tesselation", "Contours", "Iris"]

# ComboBox Style
COMBO_BOX_STYLE = """
    QComboBox {
        padding: 5px;
        margin: 10px;
        border: 1px solid #007BFF;
        border-radius: 5px;
    }
    QComboBox::drop-down {
        border: 0px;
    }
    QComboBox QAbstractItemView {
        border: 1px solid #007BFF;
        selection-background-color: #007BFF;
    }
"""
# Add this to your style.py

ROUND_BUTTON_STYLE = """
QPushButton {
    font-size: 18px;
    text-align: center;
    
    background-color: #5A9;
    color: white;
    padding: 10px;
    border-radius: 20px; /* Half of width/height */
    min-width: 25px;
    min-height: 25px;
}
QPushButton:hover {
    background-color: #7AB;
}
QPushButton:pressed {
    background-color: #489;
}
"""



import json
import cv2
import mediapipe as mp
import numpy as np
import math

# Load the PNG file paths from JSON
with open('cvtease/database/eyeAftjson.json', 'r') as file:
    data = json.load(file)
glasses_paths = data['images']

mp_drawing = mp.solutions.drawing_utils
mp_face_mesh = mp.solutions.face_mesh
current_glasses_img = cv2.imread(glasses_paths[0], cv2.IMREAD_UNCHANGED)

def load_glasses_image(path):
    global current_glasses_img
    current_glasses_img = cv2.imread(path, cv2.IMREAD_UNCHANGED)

def overlay_image_alpha(img, img_overlay, pos, alpha_mask):
    x, y = pos

    y1, y2 = max(0, y), min(img.shape[0], y + img_overlay.shape[0])
    x1, x2 = max(0, x), min(img.shape[1], x + img_overlay.shape[1])

    y1o, y2o = max(0, -y), min(img_overlay.shape[0], img.shape[0] - y)
    x1o, x2o = max(0, -x), min(img_overlay.shape[1], img.shape[1] - x)

    if y1 >= y2 or x1 >= x2 or y1o >= y2o or x1o >= x2o:
        return

    alpha = alpha_mask[y1o:y2o, x1o:x2o, np.newaxis] / 255.0
    img[y1:y2, x1:x2] = (1.0 - alpha) * img[y1:y2, x1:x2] + alpha * img_overlay[y1o:y2o, x1o:x2o]

def apply_glasses(image, landmarks):
    left_eye = landmarks[33]
    right_eye = landmarks[263]
    glasses_width = int(math.dist([left_eye.x, left_eye.y], [right_eye.x, right_eye.y]) * image.shape[1] * 1.5)
    glasses_height = int(glasses_width * current_glasses_img.shape[0] / current_glasses_img.shape[1])

    resized_glasses = cv2.resize(current_glasses_img, (glasses_width, glasses_height), interpolation=cv2.INTER_AREA)

    center_x = int((left_eye.x + right_eye.x) / 2 * image.shape[1])
    center_y = int((left_eye.y + right_eye.y) / 2 * image.shape[0])

    x = center_x - glasses_width // 2
    y = center_y - glasses_height // 2 - int(0.1 * glasses_height)

    overlay_image_alpha(image, resized_glasses[:, :, 0:3], (x, y), resized_glasses[:, :, 3])
